IsValidRefName extension
Extension methods for Git reference name validation.
- on
Methods
-
isValidRefName(
) → bool -
Available on String, provided by the IsValidRefName extension
Validates if the string is a valid Git reference name.
Extension methods for Git reference name validation.
Available on String, provided by the IsValidRefName extension
Validates if the string is a valid Git reference name.