LibGit2Error class

Represents an error that occurred in libgit2.

This class provides access to the last error that occurred in libgit2 operations. It wraps the native git_error structure and provides a Dart-friendly interface to access error information.

Constructors

LibGit2Error(Pointer<git_error> _errorPointer)
Creates a new instance of LibGit2Error from a native error pointer.

Properties

errorClass git_error_t
Gets the error class associated with this error.
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
Gets the error message associated with this error.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited