git_blame_hunk class final

Structure that represents a blame hunk.

Inheritance
Implemented types
Available extensions

Constructors

git_blame_hunk()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
boundary int
The 1 iff the hunk has been tracked to a boundary commit (the root, or the commit specified in git_blame_options.oldest_commit)
getter/setter pair
final_commit_id git_oid
The OID of the commit where this line was last changed.
getter/setter pair
final_committer Pointer<git_signature>
The committer of final_commit_id. If GIT_BLAME_USE_MAILMAP has been specified, it will contain the canonical real name and email address.
getter/setter pair
final_signature Pointer<git_signature>
The author of final_commit_id. If GIT_BLAME_USE_MAILMAP has been specified, it will contain the canonical real name and email address.
getter/setter pair
final_start_line_number int
The 1-based line number where this hunk begins, in the final version of the file.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lines_in_hunk int
The number of lines in this hunk.
getter/setter pair
orig_commit_id git_oid
The OID of the commit where this hunk was found. This will usually be the same as final_commit_id, except when GIT_BLAME_TRACK_COPIES_ANY_COMMIT_COPIES has been specified.
getter/setter pair
orig_committer Pointer<git_signature>
The committer of orig_commit_id. If GIT_BLAME_USE_MAILMAP has been specified, it will contain the canonical real name and email address.
getter/setter pair
orig_path Pointer<Char>
The path to the file where this hunk originated, as of the commit specified by orig_commit_id.
getter/setter pair
orig_signature Pointer<git_signature>
The author of orig_commit_id. If GIT_BLAME_USE_MAILMAP has been specified, it will contain the canonical real name and email address.
getter/setter pair
orig_start_line_number int
The 1-based line number where this hunk begins in the file named by orig_path in the commit specified by orig_commit_id.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary Pointer<Char>
The summary of the commit.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited