git_diff_file class final

Description of one side of a delta.

Although this is called a "file", it could represent a file, a symbolic link, a submodule commit id, or even a tree (although that only if you are tracking type changes or ignored/untracked directories).

Inheritance
Implemented types
Available extensions

Constructors

git_diff_file()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
flags int
A combination of the git_diff_flag_t types
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id git_oid
The git_oid of the item. If the entry represents an absent side of a diff (e.g. the old_file of a GIT_DELTA_ADDED delta), then the oid will be zeroes.
getter/setter pair
id_abbrev int
Represents the known length of the id field, when converted to a hex string. It is generally GIT_OID_SHA1_HEXSIZE, unless this delta was created from reading a patch file, in which case it may be abbreviated to something reasonable, like 7 characters.
getter/setter pair
mode int
Roughly, the stat() st_mode value for the item. This will be restricted to one of the git_filemode_t values.
getter/setter pair
path Pointer<Char>
The NUL-terminated path to the entry relative to the working directory of the repository.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The size of the entry in bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited