git_diff_line_cb typedef
When iterating over a diff, callback that will be made per text diff line. In this context, the provided range will be NULL.
When printing a diff, callback that will be made to output each line of text. This uses some extra GIT_DIFF_LINE_... constants for output of lines of file and hunk headers.
@param delta the delta that contains the line @param hunk the hunk that contains the line @param line the line in the diff @param payload the user-specified callback payload @return 0 or an error code
Implementation
typedef git_diff_line_cb
= ffi.Pointer<ffi.NativeFunction<git_diff_line_cbFunction>>;