git_diff_perfdata class final

Performance data from diffing

Inheritance
Implemented types
Available extensions

Constructors

git_diff_perfdata()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
oid_calculations int
< Number of ID calculations
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stat_calls int
< Number of stat() calls performed
getter/setter pair
version int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited