git_email_create_options class final

Options for controlling the formatting of the generated e-mail.

Inheritance
Implemented types
Available extensions

Constructors

git_email_create_options()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
diff_find_opts git_diff_find_options
Options for finding similarities within diffs
getter/setter pair
diff_opts git_diff_options
Options to use when creating diffs
getter/setter pair
flags int
see git_email_create_flags_t above
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
reroll_number int
The "re-roll" number. By default, there is no re-roll.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start_number int
The starting patch number; this cannot be 0. By default, this is 1.
getter/setter pair
subject_prefix Pointer<Char>
The subject prefix, by default "PATCH". If set to an empty string ("") then only the patch numbers will be shown in the prefix. If the subject_prefix is empty and patch numbers are not being shown, the prefix will be omitted entirely.
getter/setter pair
version int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited