git_libgit2_opt_t enum

Global library options

These are used to select which global option to set or get and are used in git_libgit2_opts().

Inheritance
Available extensions

Values

GIT_OPT_GET_MWINDOW_SIZE → const git_libgit2_opt_t
const git_libgit2_opt_t(0)
GIT_OPT_SET_MWINDOW_SIZE → const git_libgit2_opt_t
const git_libgit2_opt_t(1)
GIT_OPT_GET_MWINDOW_MAPPED_LIMIT → const git_libgit2_opt_t
const git_libgit2_opt_t(2)
GIT_OPT_SET_MWINDOW_MAPPED_LIMIT → const git_libgit2_opt_t
const git_libgit2_opt_t(3)
GIT_OPT_GET_SEARCH_PATH → const git_libgit2_opt_t
const git_libgit2_opt_t(4)
GIT_OPT_SET_SEARCH_PATH → const git_libgit2_opt_t
const git_libgit2_opt_t(5)
GIT_OPT_SET_CACHE_OBJECT_LIMIT → const git_libgit2_opt_t
const git_libgit2_opt_t(6)
GIT_OPT_SET_CACHE_MAX_SIZE → const git_libgit2_opt_t
const git_libgit2_opt_t(7)
GIT_OPT_ENABLE_CACHING → const git_libgit2_opt_t
const git_libgit2_opt_t(8)
GIT_OPT_GET_CACHED_MEMORY → const git_libgit2_opt_t
const git_libgit2_opt_t(9)
GIT_OPT_GET_TEMPLATE_PATH → const git_libgit2_opt_t
const git_libgit2_opt_t(10)
GIT_OPT_SET_TEMPLATE_PATH → const git_libgit2_opt_t
const git_libgit2_opt_t(11)
GIT_OPT_SET_SSL_CERT_LOCATIONS → const git_libgit2_opt_t
const git_libgit2_opt_t(12)
GIT_OPT_SET_USER_AGENT → const git_libgit2_opt_t
const git_libgit2_opt_t(13)
GIT_OPT_ENABLE_STRICT_OBJECT_CREATION → const git_libgit2_opt_t
const git_libgit2_opt_t(14)
GIT_OPT_ENABLE_STRICT_SYMBOLIC_REF_CREATION → const git_libgit2_opt_t
const git_libgit2_opt_t(15)
GIT_OPT_SET_SSL_CIPHERS → const git_libgit2_opt_t
const git_libgit2_opt_t(16)
GIT_OPT_GET_USER_AGENT → const git_libgit2_opt_t
const git_libgit2_opt_t(17)
GIT_OPT_ENABLE_OFS_DELTA → const git_libgit2_opt_t
const git_libgit2_opt_t(18)
GIT_OPT_ENABLE_FSYNC_GITDIR → const git_libgit2_opt_t
const git_libgit2_opt_t(19)
GIT_OPT_GET_WINDOWS_SHAREMODE → const git_libgit2_opt_t
const git_libgit2_opt_t(20)
GIT_OPT_SET_WINDOWS_SHAREMODE → const git_libgit2_opt_t
const git_libgit2_opt_t(21)
GIT_OPT_ENABLE_STRICT_HASH_VERIFICATION → const git_libgit2_opt_t
const git_libgit2_opt_t(22)
GIT_OPT_SET_ALLOCATOR → const git_libgit2_opt_t
const git_libgit2_opt_t(23)
GIT_OPT_ENABLE_UNSAVED_INDEX_SAFETY → const git_libgit2_opt_t
const git_libgit2_opt_t(24)
GIT_OPT_GET_PACK_MAX_OBJECTS → const git_libgit2_opt_t
const git_libgit2_opt_t(25)
GIT_OPT_SET_PACK_MAX_OBJECTS → const git_libgit2_opt_t
const git_libgit2_opt_t(26)
GIT_OPT_DISABLE_PACK_KEEP_FILE_CHECKS → const git_libgit2_opt_t
const git_libgit2_opt_t(27)
GIT_OPT_ENABLE_HTTP_EXPECT_CONTINUE → const git_libgit2_opt_t
const git_libgit2_opt_t(28)
GIT_OPT_GET_MWINDOW_FILE_LIMIT → const git_libgit2_opt_t
const git_libgit2_opt_t(29)
GIT_OPT_SET_MWINDOW_FILE_LIMIT → const git_libgit2_opt_t
const git_libgit2_opt_t(30)
GIT_OPT_SET_ODB_PACKED_PRIORITY → const git_libgit2_opt_t
const git_libgit2_opt_t(31)
GIT_OPT_SET_ODB_LOOSE_PRIORITY → const git_libgit2_opt_t
const git_libgit2_opt_t(32)
GIT_OPT_GET_EXTENSIONS → const git_libgit2_opt_t
const git_libgit2_opt_t(33)
GIT_OPT_SET_EXTENSIONS → const git_libgit2_opt_t
const git_libgit2_opt_t(34)
GIT_OPT_GET_OWNER_VALIDATION → const git_libgit2_opt_t
const git_libgit2_opt_t(35)
GIT_OPT_SET_OWNER_VALIDATION → const git_libgit2_opt_t
const git_libgit2_opt_t(36)
GIT_OPT_GET_HOMEDIR → const git_libgit2_opt_t
const git_libgit2_opt_t(37)
GIT_OPT_SET_HOMEDIR → const git_libgit2_opt_t
const git_libgit2_opt_t(38)
GIT_OPT_SET_SERVER_CONNECT_TIMEOUT → const git_libgit2_opt_t
const git_libgit2_opt_t(39)
GIT_OPT_GET_SERVER_CONNECT_TIMEOUT → const git_libgit2_opt_t
const git_libgit2_opt_t(40)
GIT_OPT_SET_SERVER_TIMEOUT → const git_libgit2_opt_t
const git_libgit2_opt_t(41)
GIT_OPT_GET_SERVER_TIMEOUT → const git_libgit2_opt_t
const git_libgit2_opt_t(42)
GIT_OPT_SET_USER_AGENT_PRODUCT → const git_libgit2_opt_t
const git_libgit2_opt_t(43)
GIT_OPT_GET_USER_AGENT_PRODUCT → const git_libgit2_opt_t
const git_libgit2_opt_t(44)
GIT_OPT_ADD_SSL_X509_CERT → const git_libgit2_opt_t
const git_libgit2_opt_t(45)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) git_libgit2_opt_t

Constants

values → const List<git_libgit2_opt_t>
A constant List of the values in this enum, in order of their declaration.