git_message_trailer class final

Represents a single git message trailer.

Inheritance
Implemented types
Available extensions

Constructors

git_message_trailer()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
key Pointer<Char>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Pointer<Char>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited