git_note_foreach_cb typedef

Callback for git_note_foreach.

@param blob_id object id of the blob containing the message @param annotated_object_id the id of the object being annotated @param payload user-specified data to the foreach function @return 0 on success, or a negative number on failure

Implementation

typedef git_note_foreach_cb
    = ffi.Pointer<ffi.NativeFunction<git_note_foreach_cbFunction>>;