git_push_update class final

Represents an update which will be performed on the remote during push

Inheritance
Implemented types
Available extensions

Constructors

git_push_update()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dst git_oid
The new target for the reference
getter/setter pair
dst_refname Pointer<Char>
The name of the reference to update on the server
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src git_oid
The current target of the reference
getter/setter pair
src_refname Pointer<Char>
The source name of the reference
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited