git_remote_completion_t enum

Argument to the completion callback which tells it which operation finished.

Inheritance
Available extensions

Values

GIT_REMOTE_COMPLETION_DOWNLOAD → const git_remote_completion_t
const git_remote_completion_t(0)
GIT_REMOTE_COMPLETION_INDEXING → const git_remote_completion_t
const git_remote_completion_t(1)
GIT_REMOTE_COMPLETION_ERROR → const git_remote_completion_t
const git_remote_completion_t(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) git_remote_completion_t

Constants

values → const List<git_remote_completion_t>
A constant List of the values in this enum, in order of their declaration.