git_stash_apply_options class final

Stash application options structure

Initialize with GIT_STASH_APPLY_OPTIONS_INIT. Alternatively, you can use git_stash_apply_options_init.

Inheritance
Implemented types
Available extensions

Constructors

git_stash_apply_options()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
checkout_options git_checkout_options
Options to use when writing files to the working directory.
getter/setter pair
flags int
See git_stash_apply_flags, above.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
progress_cb Pointer<NativeFunction<git_stash_apply_progress_cbFunction>>
Optional callback to notify the consumer of application progress.
getter/setter pair
progress_payload Pointer<Void>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited