git_status_options class final

Options to control how git_status_foreach_ext() will issue callbacks.

Initialize with GIT_STATUS_OPTIONS_INIT. Alternatively, you can use git_status_options_init.

Inheritance
Implemented types
Available extensions

Constructors

git_status_options()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
baseline Pointer<git_tree>
The baseline is the tree to be used for comparison to the working directory and index; defaults to HEAD.
getter/setter pair
flags int
The flags value is an OR'ed combination of the git_status_opt_t values above. The default is GIT_STATUS_OPT_DEFAULTS, which matches git's default behavior.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pathspec git_strarray
The pathspec is an array of path patterns to match (using fnmatch-style matching), or just an array of paths to match exactly if GIT_STATUS_OPT_DISABLE_PATHSPEC_MATCH is specified in the flags.
getter/setter pair
rename_threshold int
Threshold above which similar files will be considered renames. This is equivalent to the -M option. Defaults to 50.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
show$ git_status_show_t
no setter
show$AsInt int
The show value is one of the git_status_show_t constants that control which files to scan and in what order. The default is GIT_STATUS_SHOW_INDEX_AND_WORKDIR.
getter/setter pair
version int
The struct version; pass GIT_STATUS_OPTIONS_VERSION.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited