git_status_show_t enum

Select the files on which to report status.

With git_status_foreach_ext, this will control which changes get callbacks. With git_status_list_new, these will control which changes are included in the list.

Inheritance
Available extensions

Values

GIT_STATUS_SHOW_INDEX_AND_WORKDIR → const git_status_show_t

The default. This roughly matches git status --porcelain regarding which files are included and in what order.

const git_status_show_t(0)
GIT_STATUS_SHOW_INDEX_ONLY → const git_status_show_t

Only gives status based on HEAD to index comparison, not looking at working directory changes.

const git_status_show_t(1)
GIT_STATUS_SHOW_WORKDIR_ONLY → const git_status_show_t

Only gives status based on index to working directory comparison, not comparing the index to the HEAD.

const git_status_show_t(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) git_status_show_t

Constants

values → const List<git_status_show_t>
A constant List of the values in this enum, in order of their declaration.