git_submodule_update_options class final

Submodule update options structure

Initialize with GIT_SUBMODULE_UPDATE_OPTIONS_INIT. Alternatively, you can use git_submodule_update_options_init.

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
allow_fetch int
Allow fetching from the submodule's default remote if the target commit isn't found. Enabled by default.
getter/setter pair
checkout_opts git_checkout_options
These options are passed to the checkout step. To disable checkout, set the checkout_strategy to GIT_CHECKOUT_NONE or GIT_CHECKOUT_DRY_RUN.
getter/setter pair
fetch_opts git_fetch_options
Options which control the fetch, including callbacks.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited