git2dart_binaries library
libgit2 binaries.
Classes
- AndroidSSLHelper
- Helper class to set up SSL certificates for git2dart on Android.
- div_t
- drand48_data
- fd_set
- git_allocator
- An instance for a custom memory allocator
- git_annotated_commit
- git_apply_options
- Apply options structure.
- git_attr_options
- An options structure for querying attributes.
- git_blame
- git_blame_hunk
- Structure that represents a blame hunk.
- git_blame_line
- Structure that represents a line in a blamed file.
- git_blame_options
- Blame options structure
- git_blob
- git_blob_filter_options
- The options used when applying filter options to a file.
- git_branch_iterator
- git_buf
- A data buffer for exporting data from libgit2
- git_cert
-
Parent type for
git_cert_hostkeyandgit_cert_x509. - git_cert_hostkey
- Hostkey information taken from libssh2
- git_cert_x509
- X.509 certificate information
- git_checkout_options
- Checkout options structure
- git_checkout_perfdata
- Checkout performance-reporting structure
- git_cherrypick_options
- Cherry-pick options
- git_clone_options
- Clone options structure
- git_commit
- git_commit_create_options
- git_commit_graph
- git_commit_graph_open_options
-
Options structure for
git_commit_graph_open_new. - git_commit_graph_writer
- git_commit_graph_writer_options
-
Options structure for
git_commit_graph_writer_new. - git_commitarray
- An array of commits returned from the library
- git_config
- git_config_backend
- Generic backend that implements the interface to access a configuration file
- git_config_backend_entry
- An entry in a configuration backend. This is provided so that backend implementors can have a mechanism to free their data.
- git_config_backend_memory_options
- Options for in-memory configuration backends.
- git_config_entry
- An entry in a configuration file
- git_config_iterator
- Every iterator must have this struct as its first element, so the API can talk to it. You'd define your iterator as
- git_configmap
- Mapping from config variables to values.
- git_credential
- The base structure for all credential types
- git_credential_ssh_custom
- A key with a custom signature function
- git_credential_ssh_interactive
- Keyboard-interactive based ssh authentication
- git_credential_ssh_key
- A ssh key from disk
- git_credential_username
- Username-only credential information
- git_credential_userpass_plaintext
- A plaintext username and password
- git_describe_format_options
- Describe format options structure
- git_describe_options
- Describe options structure
- git_describe_result
- git_diff
- git_diff_binary
- Structure describing the binary contents of a diff.
- git_diff_binary_file
- The contents of one of the files in a binary diff.
- git_diff_delta
- Description of changes to one entry.
- git_diff_file
- Description of one side of a delta.
- git_diff_find_options
- Control behavior of rename and copy detection
- git_diff_hunk
- Structure describing a hunk of a diff.
- git_diff_line
- Structure describing a line (or data span) of a diff.
- git_diff_options
- Structure describing options about how the diff should be executed.
- git_diff_parse_options
- Options for parsing a diff / patch file.
- git_diff_patchid_options
- Patch ID options structure
- git_diff_perfdata
- Performance data from diffing
- git_diff_similarity_metric
- Pluggable similarity metric
- git_diff_stats
- git_email_create_options
- Options for controlling the formatting of the generated e-mail.
- git_error
- Structure to store extra details of the last error that occurred.
- git_fetch_negotiation
- The negotiation state during a fetch smart transport negotiation.
- git_fetch_options
- Fetch options structure.
- git_filter
- Filter structure used to register custom filters.
- git_filter_list
- git_filter_options
- Filtering options
- git_filter_source
- git_hashsig
- git_index
- git_index_conflict_iterator
- git_index_entry
- In-memory representation of a file entry in the index.
- git_index_iterator
- git_index_name_entry
- Representation of a rename conflict entry in the index.
- git_index_options
- The options for opening or creating an index.
- git_index_reuc_entry
- Representation of a resolve undo entry in the index.
- git_index_time
- Time structure used in a git index entry
- git_indexer
- git_indexer_options
- Options for indexer configuration
- git_indexer_progress
- This structure is used to provide callers information about the progress of indexing a packfile, either directly or part of a fetch or clone that downloads a packfile.
- git_iterator
- git_mailmap
- git_merge_driver
- Merge driver structure used to register custom merge drivers.
- git_merge_driver_source
- git_merge_file_input
-
The file inputs to
git_merge_file. Callers should populate thegit_merge_file_inputstructure with descriptions of the files in each side of the conflict for use in producing the merge file. - git_merge_file_options
- Options for merging a file
- git_merge_file_result
- Information about file-level merging
- git_merge_options
- Merging options
- git_message_trailer
- Represents a single git message trailer.
- git_message_trailer_array
- Represents an array of git message trailers.
- git_midx_writer
- git_midx_writer_options
-
Options structure for
git_midx_writer_options. - git_note
- git_object
- git_odb
- git_odb_backend
- An instance for a custom backend
- git_odb_backend_loose_options
- Options for configuring a loose object backend.
- git_odb_backend_pack_options
- Options for configuring a packfile object backend.
- git_odb_expand_id
-
The information about object IDs to query in
git_odb_expand_ids, which will be populated upon return. - git_odb_object
- git_odb_options
- Options for configuring a loose object backend.
- git_odb_stream
- A stream to read/write from a backend.
- git_odb_writepack
- A stream to write a pack file to the ODB
- git_oid
- Unique identity of any object (commit, tree, blob, tag).
- git_oid_shorten
- git_oidarray
- Array of object ids
- git_packbuilder
- git_patch
- git_pathspec
- git_pathspec_match_list
- git_proxy_options
- Options for connecting through a proxy
- git_push
- git_push_options
- Controls the behavior of a git_push object.
- git_push_update
- Represents an update which will be performed on the remote during push
- git_rebase
- git_rebase_operation
- A rebase operation
- git_rebase_options
- Rebase options
- git_refdb
- git_refdb_backend
- An instance for a custom backend
- git_reference
- git_reference_iterator
- Every backend's iterator must have a pointer to itself as the first element, so the API can talk to it. You'd define your iterator as
- git_reflog
- git_reflog_entry
- git_refspec
- git_remote
- git_remote_callbacks
- The callback settings structure
- git_remote_connect_options
- Remote creation options structure
- git_remote_create_options
- Remote creation options structure
- git_remote_head
-
Description of a reference advertised by a remote server, given out
on
lscalls. - git_repository
- git_repository_init_options
-
Extended options structure for
git_repository_init_ext. - git_repository_new_options
- The options for creating an repository from scratch.
- git_revert_options
- Options for revert
- git_revspec
-
Git Revision Spec: output of a
git_revparseoperation - git_revwalk
- git_signature
- An action signature (e.g. for committers, taggers, etc)
- git_smart_subtransport
- An implementation of a subtransport which carries data for the smart transport
- git_smart_subtransport_definition
- Definition for a "subtransport"
- git_smart_subtransport_stream
- A stream used by the smart transport to read and write data from a subtransport.
- git_stash_apply_options
- Stash application options structure
- git_stash_save_options
- Stash save options structure
- git_status_entry
- A status entry, providing the differences between the file as it exists in HEAD and the index, and providing the differences between the index and the working directory.
- git_status_list
- git_status_options
-
Options to control how
git_status_foreach_ext()will issue callbacks. - git_strarray
- Array of strings
- git_stream
- Every stream must have this struct as its first element, so the API can talk to it. You'd define your stream as
- git_stream_registration
- git_submodule
- git_submodule_update_options
- Submodule update options structure
- git_tag
- git_time
- Time in a signature
- git_transaction
- git_transport
- git_tree
- git_tree_entry
- git_tree_update
- An action to perform during the update of a tree
- git_treebuilder
- git_worktree
- git_worktree_add_options
- Worktree add options structure
- git_worktree_prune_options
- Worktree prune options structure
- git_writestream
- A type to write in a streaming fashion, for example, for filters.
- imaxdiv_t
- itimerspec
- ldiv_t
- Libgit2
- Bindings to libgit2
- LibGit2Error
- Represents an error that occurred in libgit2.
- Libgit2Opts
- Bindings to libgit2 global options.
- lldiv_t
- pthread_attr_t
- pthread_barrier_t
- pthread_barrierattr_t
- pthread_cond_t
- pthread_condattr_t
- pthread_mutex_t
- pthread_mutexattr_t
- pthread_rwlock_t
- pthread_rwlockattr_t
- random_data
- sigevent
- timespec
- timeval
- tm
- UnnamedStruct1
Enums
- git_apply_flags_t
-
Flags controlling the behavior of
git_apply. - git_apply_location_t
- Possible application locations for git_apply
- git_attr_value_t
- Possible states for an attribute
- git_blame_flag_t
- Flags for indicating option behavior for git_blame APIs.
- git_blob_filter_flag_t
-
Flags to control the functionality of
git_blob_filter. - git_branch_t
- Basic type of any Git branch.
- git_cert_ssh_raw_type_t
- git_cert_ssh_t
- Type of SSH host fingerprint
- git_cert_t
- Type of host certificate structure that is passed to the check callback
- git_checkout_notify_t
- Checkout notification flags
- git_checkout_strategy_t
- Checkout behavior flags
- git_clone_local_t
- Options for bypassing the git-aware transport on clone. Bypassing it means that instead of a fetch, libgit2 will copy the object database directory instead of figuring out what it needs, which is faster. If possible, it will hardlink the files to save space.
- git_commit_graph_split_strategy_t
- The strategy to use when adding a new set of commits to a pre-existing commit-graph chain.
- git_config_level_t
- Priority level of a config file.
- git_configmap_t
- Config var type
- git_credential_t
- Supported credential types
- git_delta_t
- What type of change is described by a git_diff_delta?
- git_describe_strategy_t
- Reference lookup strategy
- git_diff_binary_t
- When producing a binary diff, the binary data returned will be either the deflated full ("literal") contents of the file, or the deflated binary delta between the two sides (whichever is smaller).
- git_diff_find_t
- Flags to control the behavior of diff rename/copy detection.
- git_diff_flag_t
- Flags for the delta object and the file objects on each side.
- git_diff_format_t
- Possible output formats for diff data
- git_diff_line_t
- Line origin constants.
- git_diff_option_t
-
Flags for diff options. A combination of these flags can be passed
in via the
flagsvalue in thegit_diff_options. - git_diff_stats_format_t
- Formatting options for diff stats
- git_direction
- Direction of the connection.
- git_email_create_flags_t
- Formatting options for diff e-mail generation
- git_error_code
- Generic return codes
- git_error_t
- Error classes are the category of error. They reflect the area of the code where an error occurred.
- git_feature_t
- Configurable features of libgit2; either optional settings (like threading), or features that can be enabled by one of a number of different backend "providers" (like HTTPS, which can be provided by OpenSSL, mbedTLS, or system libraries).
- git_fetch_depth_t
- Constants for fetch depth (shallowness of fetch).
- git_fetch_prune_t
- Acceptable prune settings when fetching
- git_filemode_t
- Valid modes for index and tree entries.
- git_filter_flag_t
- Filter option flags.
- git_filter_mode_t
- Filters are applied in one of two directions: smudging - which is exporting a file from the Git object database to the working directory, and cleaning - which is importing a file from the working directory to the Git object database. These values control which direction of change is being applied.
- git_hashsig_option_t
- Options for hashsig computation
- git_index_add_option_t
- Flags for APIs that add files matching pathspec
- git_index_capability_t
- Capabilities of system that affect index actions.
- git_index_entry_extended_flag_t
-
Bitmasks for on-disk fields of
git_index_entry'sflags_extended - git_index_entry_flag_t
- Flags for index entries
- git_index_stage_t
- Git index stage states
- git_libgit2_opt_t
- Global library options
- git_merge_analysis_t
-
The results of
git_merge_analysisindicate the merge opportunities. - git_merge_file_favor_t
-
Merge file favor options for
git_merge_optionsinstruct the file-level merging functionality how to deal with conflicting regions of the files. - git_merge_file_flag_t
- File merging flags
- git_merge_flag_t
-
Flags for
git_mergeoptions. A combination of these flags can be passed in via theflagsvalue in thegit_merge_options. - git_merge_preference_t
- The user's stated preference for merges.
- git_object_t
- Basic type (loose or packed) of any Git object.
- git_odb_backend_loose_flag_t
- git_odb_lookup_flags_t
- Flags controlling the behavior of ODB lookup operations
- git_odb_stream_t
- Streaming mode
- git_oid_t
- The type of object id.
- git_packbuilder_stage_t
- Stages that are reported by the packbuilder progress callback.
- git_path_fs
- The kinds of checks to perform according to which filesystem we are trying to protect.
- git_path_gitfile
- The kinds of git-specific files we know about.
- git_pathspec_flag_t
- Options controlling how pathspec match should be executed
- git_proxy_t
- The type of proxy to use.
- git_rebase_operation_t
-
Type of rebase operation in-progress after calling
git_rebase_next. - git_reference_format_t
- Normalization options for reference lookup
- git_reference_t
- Basic type of any Git reference.
- git_remote_autotag_option_t
- Automatic tag following option
- git_remote_capability_t
- A remote's capabilities.
- git_remote_completion_t
- Argument to the completion callback which tells it which operation finished.
- git_remote_create_flags
- Remote creation options flags
- git_remote_redirect_t
-
Remote redirection settings; whether redirects to another host
are permitted. By default, git will follow a redirect on the
initial request (
/info/refs), but not subsequent requests. - git_remote_update_flags
- How to handle reference updates.
- git_repository_init_flag_t
-
Option flags for
git_repository_init_ext. - git_repository_init_mode_t
-
Mode options for
git_repository_init_ext. - git_repository_item_t
- List of items which belong to the git repository layout
- git_repository_open_flag_t
-
Option flags for
git_repository_open_ext. - git_repository_state_t
- Repository state
- git_reset_t
- Kinds of reset operation
- git_revspec_t
- Revparse flags. These indicate the intended behavior of the spec passed to git_revparse.
- git_smart_service_t
- Actions that the smart transport can ask a subtransport to perform
- git_sort_t
- Flags to specify the sorting which a revwalk should perform.
- git_stash_apply_flags
- Stash application flags.
- git_stash_apply_progress_t
- Stash apply progression states
- git_stash_flags
- Stash flags
- git_status_opt_t
- Flags to control status callbacks
- git_status_show_t
- Select the files on which to report status.
- git_status_t
- Status flags for a single file.
- git_stream_t
- The type of stream to register.
- git_submodule_ignore_t
- Submodule ignore values
- git_submodule_recurse_t
- Options for submodule recurse.
- git_submodule_status_t
- Return codes for submodule status.
- git_submodule_update_t
- Submodule update values
- git_tree_update_t
- The kind of update to perform
- git_treewalk_mode
- Tree traversal modes
- git_worktree_prune_t
- Flags which can be passed to git_worktree_prune to alter its behavior.
Extensions
- GetLastError on Libgit2
- Extension methods for Git object type validation.
- IsValidGitObjectType on int
- Extension methods for Git object type validation.
- IsValidRefName on String
- Extension methods for Git reference name validation.
- IsValidSHA on String
- Extension methods for String validation and conversion.
-
ToDartString
on Pointer<
Char> - Extension methods for converting C char pointer to Dart String.
Constants
- BIG_ENDIAN → const int
- BYTE_ORDER → const int
- CLOCK_BOOTTIME → const int
- CLOCK_BOOTTIME_ALARM → const int
- CLOCK_MONOTONIC → const int
- CLOCK_MONOTONIC_COARSE → const int
- CLOCK_MONOTONIC_RAW → const int
- CLOCK_PROCESS_CPUTIME_ID → const int
- CLOCK_REALTIME → const int
- CLOCK_REALTIME_ALARM → const int
- CLOCK_REALTIME_COARSE → const int
- CLOCK_TAI → const int
- CLOCK_THREAD_CPUTIME_ID → const int
- CLOCKS_PER_SEC → const int
- EXIT_FAILURE → const int
- EXIT_SUCCESS → const int
- FD_SETSIZE → const int
- GIT_APPLY_OPTIONS_VERSION → const int
- GIT_ATTR_CHECK_FILE_THEN_INDEX → const int
- GIT_ATTR_CHECK_INCLUDE_COMMIT → const int
- GIT_ATTR_CHECK_INCLUDE_HEAD → const int
- GIT_ATTR_CHECK_INDEX_ONLY → const int
- GIT_ATTR_CHECK_INDEX_THEN_FILE → const int
- GIT_ATTR_CHECK_NO_SYSTEM → const int
- GIT_ATTR_OPTIONS_VERSION → const int
- GIT_BLAME_OPTIONS_VERSION → const int
- GIT_BLOB_FILTER_OPTIONS_VERSION → const int
- GIT_CHECKOUT_OPTIONS_VERSION → const int
- GIT_CHERRYPICK_OPTIONS_VERSION → const int
- GIT_CLONE_OPTIONS_VERSION → const int
- GIT_COMMIT_CREATE_OPTIONS_VERSION → const int
- GIT_COMMIT_GRAPH_OPEN_OPTIONS_VERSION → const int
- GIT_COMMIT_GRAPH_WRITER_OPTIONS_VERSION → const int
- GIT_CONFIG_BACKEND_MEMORY_OPTIONS_VERSION → const int
- GIT_CONFIG_BACKEND_VERSION → const int
- GIT_DEFAULT_PORT → const String
- GIT_DESCRIBE_DEFAULT_ABBREVIATED_SIZE → const int
- GIT_DESCRIBE_DEFAULT_MAX_CANDIDATES_TAGS → const int
- GIT_DESCRIBE_FORMAT_OPTIONS_VERSION → const int
- GIT_DESCRIBE_OPTIONS_VERSION → const int
- GIT_DIFF_FIND_OPTIONS_VERSION → const int
- GIT_DIFF_HUNK_HEADER_SIZE → const int
- GIT_DIFF_OPTIONS_VERSION → const int
- GIT_DIFF_PARSE_OPTIONS_VERSION → const int
- GIT_DIFF_PATCHID_OPTIONS_VERSION → const int
- GIT_DIFF_PERFDATA_VERSION → const int
- GIT_EMAIL_CREATE_OPTIONS_VERSION → const int
- GIT_FETCH_OPTIONS_VERSION → const int
- GIT_FILTER_CRLF → const String
- GIT_FILTER_CRLF_PRIORITY → const int
- GIT_FILTER_DRIVER_PRIORITY → const int
- GIT_FILTER_IDENT → const String
- GIT_FILTER_IDENT_PRIORITY → const int
- GIT_FILTER_OPTIONS_VERSION → const int
- GIT_FILTER_VERSION → const int
- GIT_INDEX_ENTRY_NAMEMASK → const int
- GIT_INDEX_ENTRY_STAGEMASK → const int
- GIT_INDEX_ENTRY_STAGESHIFT → const int
- GIT_INDEX_OPTIONS_VERSION → const int
- GIT_INDEXER_OPTIONS_VERSION → const int
- GIT_MERGE_CONFLICT_MARKER_SIZE → const int
- GIT_MERGE_DRIVER_BINARY → const String
- GIT_MERGE_DRIVER_TEXT → const String
- GIT_MERGE_DRIVER_UNION → const String
- GIT_MERGE_DRIVER_VERSION → const int
- GIT_MERGE_FILE_INPUT_VERSION → const int
- GIT_MERGE_FILE_OPTIONS_VERSION → const int
- GIT_MERGE_OPTIONS_VERSION → const int
- GIT_MIDX_WRITER_OPTIONS_VERSION → const int
- GIT_OBJECT_SIZE_MAX → const int
- GIT_ODB_BACKEND_LOOSE_OPTIONS_VERSION → const int
- GIT_ODB_BACKEND_PACK_OPTIONS_VERSION → const int
- GIT_ODB_BACKEND_VERSION → const int
- GIT_ODB_OPTIONS_VERSION → const int
- GIT_OID_DEFAULT → const int
- GIT_OID_MAX_HEXSIZE → const int
- GIT_OID_MAX_SIZE → const int
- GIT_OID_MINPREFIXLEN → const int
- GIT_OID_SHA1_HEXSIZE → const int
- GIT_OID_SHA1_HEXZERO → const String
- GIT_OID_SHA1_SIZE → const int
- GIT_OID_SHA256_HEXSIZE → const int
- GIT_OID_SHA256_HEXZERO → const String
- GIT_OID_SHA256_SIZE → const int
- GIT_PATH_LIST_SEPARATOR → const int
- GIT_PATH_MAX → const int
- GIT_PROXY_OPTIONS_VERSION → const int
- GIT_PUSH_OPTIONS_VERSION → const int
- GIT_REBASE_NO_OPERATION → const int
- GIT_REBASE_OPTIONS_VERSION → const int
- GIT_REFDB_BACKEND_VERSION → const int
- GIT_REMOTE_CALLBACKS_VERSION → const int
- GIT_REMOTE_CONNECT_OPTIONS_VERSION → const int
- GIT_REMOTE_CREATE_OPTIONS_VERSION → const int
- GIT_REPOSITORY_INIT_OPTIONS_VERSION → const int
- GIT_REPOSITORY_NEW_OPTIONS_VERSION → const int
- GIT_REVERT_OPTIONS_VERSION → const int
- GIT_STASH_APPLY_OPTIONS_VERSION → const int
- GIT_STASH_SAVE_OPTIONS_VERSION → const int
- GIT_STATUS_OPT_DEFAULTS → const int
- GIT_STATUS_OPTIONS_VERSION → const int
- GIT_STREAM_VERSION → const int
- GIT_SUBMODULE_STATUS__IN_FLAGS → const int
- GIT_SUBMODULE_STATUS__INDEX_FLAGS → const int
- GIT_SUBMODULE_STATUS__WD_FLAGS → const int
- GIT_SUBMODULE_UPDATE_OPTIONS_VERSION → const int
- GIT_TRANSPORT_VERSION → const int
- GIT_WORKTREE_ADD_OPTIONS_VERSION → const int
- GIT_WORKTREE_PRUNE_OPTIONS_VERSION → const int
- INT16_MAX → const int
- INT16_MIN → const int
- INT32_MAX → const int
- INT32_MIN → const int
- INT64_MAX → const int
- INT64_MIN → const int
- INT8_MAX → const int
- INT8_MIN → const int
- INT_FAST16_MAX → const int
- INT_FAST16_MIN → const int
- INT_FAST32_MAX → const int
- INT_FAST32_MIN → const int
- INT_FAST64_MAX → const int
- INT_FAST64_MIN → const int
- INT_FAST8_MAX → const int
- INT_FAST8_MIN → const int
- INT_LEAST16_MAX → const int
- INT_LEAST16_MIN → const int
- INT_LEAST32_MAX → const int
- INT_LEAST32_MIN → const int
- INT_LEAST64_MAX → const int
- INT_LEAST64_MIN → const int
- INT_LEAST8_MAX → const int
- INT_LEAST8_MIN → const int
- INTMAX_MAX → const int
- INTMAX_MIN → const int
- INTPTR_MAX → const int
- INTPTR_MIN → const int
- LIBGIT2_SOVERSION → const String
- LIBGIT2_VERSION → const String
- LIBGIT2_VERSION_MAJOR → const int
- LIBGIT2_VERSION_MINOR → const int
- LIBGIT2_VERSION_NUMBER → const int
- LIBGIT2_VERSION_PATCH → const int
- LIBGIT2_VERSION_PRERELEASE → const int
- LIBGIT2_VERSION_REVISION → const int
- LITTLE_ENDIAN → const int
- NFDBITS → const int
- NULL → const int
- PDP_ENDIAN → const int
- PRId16 → const String
- PRId32 → const String
- PRId64 → const String
- PRId8 → const String
- PRIdFAST16 → const String
- PRIdFAST32 → const String
- PRIdFAST64 → const String
- PRIdFAST8 → const String
- PRIdLEAST16 → const String
- PRIdLEAST32 → const String
- PRIdLEAST64 → const String
- PRIdLEAST8 → const String
- PRIdMAX → const String
- PRIdPTR → const String
- PRIi16 → const String
- PRIi32 → const String
- PRIi64 → const String
- PRIi8 → const String
- PRIiFAST16 → const String
- PRIiFAST32 → const String
- PRIiFAST64 → const String
- PRIiFAST8 → const String
- PRIiLEAST16 → const String
- PRIiLEAST32 → const String
- PRIiLEAST64 → const String
- PRIiLEAST8 → const String
- PRIiMAX → const String
- PRIiPTR → const String
- PRIo16 → const String
- PRIo32 → const String
- PRIo64 → const String
- PRIo8 → const String
- PRIoFAST16 → const String
- PRIoFAST32 → const String
- PRIoFAST64 → const String
- PRIoFAST8 → const String
- PRIoLEAST16 → const String
- PRIoLEAST32 → const String
- PRIoLEAST64 → const String
- PRIoLEAST8 → const String
- PRIoMAX → const String
- PRIoPTR → const String
- PRIu16 → const String
- PRIu32 → const String
- PRIu64 → const String
- PRIu8 → const String
- PRIuFAST16 → const String
- PRIuFAST32 → const String
- PRIuFAST64 → const String
- PRIuFAST8 → const String
- PRIuLEAST16 → const String
- PRIuLEAST32 → const String
- PRIuLEAST64 → const String
- PRIuLEAST8 → const String
- PRIuMAX → const String
- PRIuPTR → const String
- PRIX16 → const String
- PRIx16 → const String
- PRIX32 → const String
- PRIx32 → const String
- PRIX64 → const String
- PRIx64 → const String
- PRIX8 → const String
- PRIx8 → const String
- PRIXFAST16 → const String
- PRIxFAST16 → const String
- PRIXFAST32 → const String
- PRIxFAST32 → const String
- PRIXFAST64 → const String
- PRIxFAST64 → const String
- PRIXFAST8 → const String
- PRIxFAST8 → const String
- PRIXLEAST16 → const String
- PRIxLEAST16 → const String
- PRIXLEAST32 → const String
- PRIxLEAST32 → const String
- PRIXLEAST64 → const String
- PRIxLEAST64 → const String
- PRIXLEAST8 → const String
- PRIxLEAST8 → const String
- PRIXMAX → const String
- PRIxMAX → const String
- PRIXPTR → const String
- PRIxPTR → const String
- PTRDIFF_MAX → const int
- PTRDIFF_MIN → const int
- RAND_MAX → const int
- SCNd16 → const String
- SCNd32 → const String
- SCNd64 → const String
- SCNd8 → const String
- SCNdFAST16 → const String
- SCNdFAST32 → const String
- SCNdFAST64 → const String
- SCNdFAST8 → const String
- SCNdLEAST16 → const String
- SCNdLEAST32 → const String
- SCNdLEAST64 → const String
- SCNdLEAST8 → const String
- SCNdMAX → const String
- SCNdPTR → const String
- SCNi16 → const String
- SCNi32 → const String
- SCNi64 → const String
- SCNi8 → const String
- SCNiFAST16 → const String
- SCNiFAST32 → const String
- SCNiFAST64 → const String
- SCNiFAST8 → const String
- SCNiLEAST16 → const String
- SCNiLEAST32 → const String
- SCNiLEAST64 → const String
- SCNiLEAST8 → const String
- SCNiMAX → const String
- SCNiPTR → const String
- SCNo16 → const String
- SCNo32 → const String
- SCNo64 → const String
- SCNo8 → const String
- SCNoFAST16 → const String
- SCNoFAST32 → const String
- SCNoFAST64 → const String
- SCNoFAST8 → const String
- SCNoLEAST16 → const String
- SCNoLEAST32 → const String
- SCNoLEAST64 → const String
- SCNoLEAST8 → const String
- SCNoMAX → const String
- SCNoPTR → const String
- SCNu16 → const String
- SCNu32 → const String
- SCNu64 → const String
- SCNu8 → const String
- SCNuFAST16 → const String
- SCNuFAST32 → const String
- SCNuFAST64 → const String
- SCNuFAST8 → const String
- SCNuLEAST16 → const String
- SCNuLEAST32 → const String
- SCNuLEAST64 → const String
- SCNuLEAST8 → const String
- SCNuMAX → const String
- SCNuPTR → const String
- SCNx16 → const String
- SCNx32 → const String
- SCNx64 → const String
- SCNx8 → const String
- SCNxFAST16 → const String
- SCNxFAST32 → const String
- SCNxFAST64 → const String
- SCNxFAST8 → const String
- SCNxLEAST16 → const String
- SCNxLEAST32 → const String
- SCNxLEAST64 → const String
- SCNxLEAST8 → const String
- SCNxMAX → const String
- SCNxPTR → const String
- SIG_ATOMIC_MAX → const int
- SIG_ATOMIC_MIN → const int
- SIZE_MAX → const int
- TIME_UTC → const int
- TIMER_ABSTIME → const int
- UINT16_MAX → const int
- UINT32_MAX → const int
- UINT64_MAX → const int
- UINT8_MAX → const int
- UINT_FAST16_MAX → const int
- UINT_FAST32_MAX → const int
- UINT_FAST64_MAX → const int
- UINT_FAST8_MAX → const int
- UINT_LEAST16_MAX → const int
- UINT_LEAST32_MAX → const int
- UINT_LEAST64_MAX → const int
- UINT_LEAST8_MAX → const int
- UINTMAX_MAX → const int
- UINTPTR_MAX → const int
- WCHAR_MAX → const int
- WCHAR_MIN → const int
- WCONTINUED → const int
- WEXITED → const int
- WINT_MAX → const int
- WINT_MIN → const int
- WNOHANG → const int
- WNOWAIT → const int
- WSTOPPED → const int
- WUNTRACED → const int
Properties
- libgit2 → Libgit2
-
final
- libgit2Opts → Libgit2Opts
-
final
Typedefs
- blkcnt_t = __blkcnt_t
- blksize_t = __blksize_t
- caddr_t = __caddr_t
- clock_t = __clock_t
- clockid_t = __clockid_t
- daddr_t = __daddr_t
- Dart__blkcnt64_t = int
- Dart__blkcnt_t = int
- Dart__blksize_t = int
- Dart__clock_t = int
- Dart__clockid_t = int
-
Dart__compar_fn_tFunction
= int Function(Pointer<
Void> , Pointer<Void> ) - Dart__daddr_t = int
- Dart__dev_t = int
- Dart__fd_mask = int
- Dart__fsblkcnt64_t = int
- Dart__fsblkcnt_t = int
- Dart__fsfilcnt64_t = int
- Dart__fsfilcnt_t = int
- Dart__fsword_t = int
- Dart__gid_t = int
- Dart__gwchar_t = int
- Dart__id_t = int
- Dart__ino64_t = int
- Dart__ino_t = int
- Dart__int16_t = int
- Dart__int32_t = int
- Dart__int64_t = int
- Dart__int8_t = int
- Dart__intmax_t = int
- Dart__intptr_t = int
- Dart__key_t = int
- Dart__mode_t = int
- Dart__nlink_t = int
- Dart__off64_t = int
- Dart__off_t = int
- Dart__pid_t = int
- Dart__quad_t = int
- Dart__rlim64_t = int
- Dart__rlim_t = int
- Dart__sig_atomic_t = int
- Dart__socklen_t = int
- Dart__ssize_t = int
- Dart__suseconds64_t = int
- Dart__suseconds_t = int
- Dart__syscall_slong_t = int
- Dart__syscall_ulong_t = int
- Dart__thrd_t = int
- Dart__time_t = int
- Dart__tss_t = int
- Dart__u_char = int
- Dart__u_int = int
- Dart__u_long = int
- Dart__u_quad_t = int
- Dart__u_short = int
- Dart__uid_t = int
- Dart__uint16_t = int
- Dart__uint32_t = int
- Dart__uint64_t = int
- Dart__uint8_t = int
- Dart__uintmax_t = int
- Dart__useconds_t = int
- Dart_Float32 = double
- Dart_Float32x = double
- Dart_Float64 = double
-
Dartgit_apply_delta_cbFunction
= int Function(Pointer<
git_diff_delta> delta, Pointer<Void> payload) -
Dartgit_apply_hunk_cbFunction
= int Function(Pointer<
git_diff_hunk> hunk, Pointer<Void> payload) -
Dartgit_attr_foreach_cbFunction
= int Function(Pointer<
Char> name, Pointer<Char> value, Pointer<Void> payload) -
Dartgit_checkout_notify_cbFunction
= int Function(git_checkout_notify_t why, Pointer<
Char> path, Pointer<git_diff_file> baseline, Pointer<git_diff_file> target, Pointer<git_diff_file> workdir, Pointer<Void> payload) -
Dartgit_checkout_perfdata_cbFunction
= void Function(Pointer<
git_checkout_perfdata> perfdata, Pointer<Void> payload) -
Dartgit_checkout_progress_cbFunction
= void Function(Pointer<
Char> path, int completed_steps, int total_steps, Pointer<Void> payload) -
Dartgit_commit_create_cbFunction
= int Function(Pointer<
git_oid> out, Pointer<git_signature> author, Pointer<git_signature> committer, Pointer<Char> message_encoding, Pointer<Char> message, Pointer<git_tree> tree, int parent_count, Pointer<Pointer< parents, Pointer<git_commit> >Void> payload) -
Dartgit_commit_parent_callbackFunction
= Pointer<
git_oid> Function(int idx, Pointer<Void> payload) -
Dartgit_config_foreach_cbFunction
= int Function(Pointer<
git_config_entry> entry, Pointer<Void> payload) -
Dartgit_credential_acquire_cbFunction
= int Function(Pointer<
Pointer< out, Pointer<git_credential> >Char> url, Pointer<Char> username_from_url, int allowed_types, Pointer<Void> payload) -
Dartgit_credential_sign_cbFunction
= int Function(Pointer<
LIBSSH2_SESSION> session, Pointer<Pointer< sig, Pointer<UnsignedChar> >Size> sig_len, Pointer<UnsignedChar> data, int data_len, Pointer<Pointer< abstract$)Void> > -
Dartgit_credential_ssh_interactive_cbFunction
= void Function(Pointer<
Char> name, int name_len, Pointer<Char> instruction, int instruction_len, int num_prompts, Pointer<LIBSSH2_USERAUTH_KBDINT_PROMPT> prompts, Pointer<LIBSSH2_USERAUTH_KBDINT_RESPONSE> responses, Pointer<Pointer< abstract$)Void> > -
Dartgit_diff_binary_cbFunction
= int Function(Pointer<
git_diff_delta> delta, Pointer<git_diff_binary> binary, Pointer<Void> payload) -
Dartgit_diff_file_cbFunction
= int Function(Pointer<
git_diff_delta> delta, double progress, Pointer<Void> payload) -
Dartgit_diff_hunk_cbFunction
= int Function(Pointer<
git_diff_delta> delta, Pointer<git_diff_hunk> hunk, Pointer<Void> payload) -
Dartgit_diff_line_cbFunction
= int Function(Pointer<
git_diff_delta> delta, Pointer<git_diff_hunk> hunk, Pointer<git_diff_line> line, Pointer<Void> payload) -
Dartgit_diff_notify_cbFunction
= int Function(Pointer<
git_diff> diff_so_far, Pointer<git_diff_delta> delta_to_add, Pointer<Char> matched_pathspec, Pointer<Void> payload) -
Dartgit_diff_progress_cbFunction
= int Function(Pointer<
git_diff> diff_so_far, Pointer<Char> old_path, Pointer<Char> new_path, Pointer<Void> payload) -
Dartgit_filter_apply_fnFunction
= int Function(Pointer<
git_filter> self, Pointer<Pointer< payload, Pointer<Void> >git_buf> to, Pointer<git_buf> from, Pointer<git_filter_source> src) -
Dartgit_filter_check_fnFunction
= int Function(Pointer<
git_filter> self, Pointer<Pointer< payload, Pointer<Void> >git_filter_source> src, Pointer<Pointer< attr_values)Char> > -
Dartgit_filter_cleanup_fnFunction
= void Function(Pointer<
git_filter> self, Pointer<Void> payload) -
Dartgit_filter_init_fnFunction
= int Function(Pointer<
git_filter> self) -
Dartgit_filter_shutdown_fnFunction
= void Function(Pointer<
git_filter> self) -
Dartgit_filter_stream_fnFunction
= int Function(Pointer<
Pointer< out, Pointer<git_writestream> >git_filter> self, Pointer<Pointer< payload, Pointer<Void> >git_filter_source> src, Pointer<git_writestream> next) -
Dartgit_index_matched_path_cbFunction
= int Function(Pointer<
Char> name, Pointer<Char> value, Pointer<Void> payload) -
Dartgit_indexer_progress_cbFunction
= int Function(Pointer<
git_indexer_progress> stats, Pointer<Void> payload) -
Dartgit_merge_driver_apply_fnFunction
= int Function(Pointer<
git_merge_driver> self, Pointer<Pointer< path_out, Pointer<Char> >Uint32> mode_out, Pointer<git_buf> merged_out, Pointer<Char> filter_name, Pointer<git_merge_driver_source> src) -
Dartgit_merge_driver_init_fnFunction
= int Function(Pointer<
git_merge_driver> self) -
Dartgit_merge_driver_shutdown_fnFunction
= void Function(Pointer<
git_merge_driver> self) -
Dartgit_note_foreach_cbFunction
= int Function(Pointer<
git_oid> blob_id, Pointer<git_oid> annotated_object_id, Pointer<Void> payload) - Dartgit_object_size_t = int
-
Dartgit_odb_foreach_cbFunction
= int Function(Pointer<
git_oid> id, Pointer<Void> payload) - Dartgit_off_t = int
-
Dartgit_packbuilder_foreach_cbFunction
= int Function(Pointer<
Void> buf, int size, Pointer<Void> payload) -
Dartgit_packbuilder_progressFunction
= int Function(int stage, int current, int total, Pointer<
Void> payload) -
Dartgit_push_negotiationFunction
= int Function(Pointer<
Pointer< updates, int len, Pointer<git_push_update> >Void> payload) -
Dartgit_push_transfer_progress_cbFunction
= int Function(int stage, int current, int total, Pointer<
Void> payload) -
Dartgit_push_update_reference_cbFunction
= int Function(Pointer<
Char> name, Pointer<Char> value, Pointer<Void> payload) -
Dartgit_reference_foreach_cbFunction
= int Function(Pointer<
git_reference> reference, Pointer<Void> payload) -
Dartgit_reference_foreach_name_cbFunction
= int Function(Pointer<
Char> name, Pointer<Void> payload) -
Dartgit_remote_create_cbFunction
= int Function(Pointer<
Pointer< out, Pointer<git_remote> >git_repository> repo, Pointer<Char> name, Pointer<Char> url, Pointer<Void> payload) -
Dartgit_remote_ready_cbFunction
= int Function(Pointer<
git_remote> remote, int direction, Pointer<Void> payload) -
Dartgit_repository_create_cbFunction
= int Function(Pointer<
Pointer< out, Pointer<git_repository> >Char> path, int bare, Pointer<Void> payload) -
Dartgit_repository_fetchhead_foreach_cbFunction
= int Function(Pointer<
Char> ref_name, Pointer<Char> remote_url, Pointer<git_oid> oid, int is_merge, Pointer<Void> payload) -
Dartgit_repository_mergehead_foreach_cbFunction
= int Function(Pointer<
git_oid> id, Pointer<Void> payload) -
Dartgit_revwalk_hide_cbFunction
= int Function(Pointer<
git_oid> id, Pointer<Void> payload) -
Dartgit_smart_subtransport_cbFunction
= int Function(Pointer<
Pointer< out, Pointer<git_smart_subtransport> >git_transport> owner, Pointer<Void> param) -
Dartgit_stash_apply_progress_cbFunction
= int Function(git_stash_apply_progress_t progress, Pointer<
Void> payload) -
Dartgit_stash_cbFunction
= int Function(int index, Pointer<
Char> message, Pointer<git_oid> stash_id, Pointer<Void> payload) -
Dartgit_status_cbFunction
= int Function(Pointer<
Char> path, int status_flags, Pointer<Void> payload) -
Dartgit_stream_cbFunction
= int Function(Pointer<
Pointer< out, Pointer<git_stream> >Char> host, Pointer<Char> port) -
Dartgit_submodule_cbFunction
= int Function(Pointer<
git_submodule> sm, Pointer<Char> name, Pointer<Void> payload) -
Dartgit_tag_foreach_cbFunction
= int Function(Pointer<
Char> name, Pointer<git_oid> oid, Pointer<Void> payload) - Dartgit_time_t = int
-
Dartgit_transport_cbFunction
= int Function(Pointer<
Pointer< out, Pointer<git_transport> >git_remote> owner, Pointer<Void> param) -
Dartgit_transport_certificate_check_cbFunction
= int Function(Pointer<
git_cert> cert, int valid, Pointer<Char> host, Pointer<Void> payload) -
Dartgit_transport_message_cbFunction
= int Function(Pointer<
Char> path, int status_flags, Pointer<Void> payload) -
Dartgit_treebuilder_filter_cbFunction
= int Function(Pointer<
git_tree_entry> entry, Pointer<Void> payload) -
Dartgit_treewalk_cbFunction
= int Function(Pointer<
Char> root, Pointer<git_tree_entry> entry, Pointer<Void> payload) -
Dartgit_url_resolve_cbFunction
= int Function(Pointer<
git_buf> url_resolved, Pointer<Char> url, int direction, Pointer<Void> payload) - Dartint_fast16_t = int
- Dartint_fast32_t = int
- Dartint_fast64_t = int
- Dartint_fast8_t = int
- Dartpthread_key_t = int
- Dartpthread_once_t = int
- Dartpthread_t = int
- Dartregister_t = int
- Dartuint = int
- Dartuint_fast16_t = int
- Dartuint_fast32_t = int
- Dartuint_fast64_t = int
- Dartuint_fast8_t = int
- Dartulong = int
- Dartushort = int
- dev_t = __dev_t
- fd_mask = __fd_mask
- fsblkcnt_t = __fsblkcnt_t
- fsfilcnt_t = __fsfilcnt_t
- fsid_t = __fsid_t
- gid_t = __gid_t
-
git_apply_delta_cb
= Pointer<
NativeFunction< git_apply_delta_cbFunction> > - When applying a patch, callback that will be made per delta (file).
-
git_apply_delta_cbFunction
= Int Function(Pointer<
git_diff_delta> delta, Pointer<Void> payload) -
git_apply_hunk_cb
= Pointer<
NativeFunction< git_apply_hunk_cbFunction> > - When applying a patch, callback that will be made per hunk.
-
git_apply_hunk_cbFunction
= Int Function(Pointer<
git_diff_hunk> hunk, Pointer<Void> payload) -
git_attr_foreach_cb
= Pointer<
NativeFunction< git_attr_foreach_cbFunction> > - The callback used with git_attr_foreach.
-
git_attr_foreach_cbFunction
= Int Function(Pointer<
Char> name, Pointer<Char> value, Pointer<Void> payload) -
git_checkout_notify_cb
= Pointer<
NativeFunction< git_checkout_notify_cbFunction> > - Checkout notification callback function.
-
git_checkout_notify_cbFunction
= Int Function(UnsignedInt why, Pointer<
Char> path, Pointer<git_diff_file> baseline, Pointer<git_diff_file> target, Pointer<git_diff_file> workdir, Pointer<Void> payload) -
git_checkout_perfdata_cb
= Pointer<
NativeFunction< git_checkout_perfdata_cbFunction> > - Checkout performance data reporting function.
-
git_checkout_perfdata_cbFunction
= Void Function(Pointer<
git_checkout_perfdata> perfdata, Pointer<Void> payload) -
git_checkout_progress_cb
= Pointer<
NativeFunction< git_checkout_progress_cbFunction> > - Checkout progress notification function.
-
git_checkout_progress_cbFunction
= Void Function(Pointer<
Char> path, Size completed_steps, Size total_steps, Pointer<Void> payload) -
git_commit_create_cb
= Pointer<
NativeFunction< git_commit_create_cbFunction> > -
Commit creation callback: used when a function is going to create
commits (for example, in
git_rebase_commit) to allow callers to override the commit creation behavior. For example, users may wish to sign commits by providing this information togit_commit_create_buffer, signing that buffer, then callinggit_commit_create_with_signature. The resultant commit id should be set in theoutobject id parameter. -
git_commit_create_cbFunction
= Int Function(Pointer<
git_oid> out, Pointer<git_signature> author, Pointer<git_signature> committer, Pointer<Char> message_encoding, Pointer<Char> message, Pointer<git_tree> tree, Size parent_count, Pointer<Pointer< parents, Pointer<git_commit> >Void> payload) -
git_commit_parent_callback
= Pointer<
NativeFunction< git_commit_parent_callbackFunction> > - Callback function to return parents for commit.
-
git_commit_parent_callbackFunction
= Pointer<
git_oid> Function(Size idx, Pointer<Void> payload) -
git_config_foreach_cb
= Pointer<
NativeFunction< git_config_foreach_cbFunction> > - A config enumeration callback.
-
git_config_foreach_cbFunction
= Int Function(Pointer<
git_config_entry> entry, Pointer<Void> payload) -
git_credential_acquire_cb
= Pointer<
NativeFunction< git_credential_acquire_cbFunction> > - Credential acquisition callback.
-
git_credential_acquire_cbFunction
= Int Function(Pointer<
Pointer< out, Pointer<git_credential> >Char> url, Pointer<Char> username_from_url, UnsignedInt allowed_types, Pointer<Void> payload) - git_credential_default = git_credential
- A key for NTLM/Kerberos "default" credentials
-
git_credential_sign_cb
= Pointer<
NativeFunction< git_credential_sign_cbFunction> > - Callback for credential signing.
-
git_credential_sign_cbFunction
= Int Function(Pointer<
LIBSSH2_SESSION> session, Pointer<Pointer< sig, Pointer<UnsignedChar> >Size> sig_len, Pointer<UnsignedChar> data, Size data_len, Pointer<Pointer< abstract$)Void> > -
git_credential_ssh_interactive_cb
= Pointer<
NativeFunction< git_credential_ssh_interactive_cbFunction> > - Callback for interactive SSH credentials.
-
git_credential_ssh_interactive_cbFunction
= Void Function(Pointer<
Char> name, Int name_len, Pointer<Char> instruction, Int instruction_len, Int num_prompts, Pointer<LIBSSH2_USERAUTH_KBDINT_PROMPT> prompts, Pointer<LIBSSH2_USERAUTH_KBDINT_RESPONSE> responses, Pointer<Pointer< abstract$)Void> > -
git_diff_binary_cb
= Pointer<
NativeFunction< git_diff_binary_cbFunction> > - When iterating over a diff, callback that will be made for binary content within the diff.
-
git_diff_binary_cbFunction
= Int Function(Pointer<
git_diff_delta> delta, Pointer<git_diff_binary> binary, Pointer<Void> payload) -
git_diff_file_cb
= Pointer<
NativeFunction< git_diff_file_cbFunction> > - When iterating over a diff, callback that will be made per file.
-
git_diff_file_cbFunction
= Int Function(Pointer<
git_diff_delta> delta, Float progress, Pointer<Void> payload) -
git_diff_hunk_cb
= Pointer<
NativeFunction< git_diff_hunk_cbFunction> > - When iterating over a diff, callback that will be made per hunk.
-
git_diff_hunk_cbFunction
= Int Function(Pointer<
git_diff_delta> delta, Pointer<git_diff_hunk> hunk, Pointer<Void> payload) -
git_diff_line_cb
= Pointer<
NativeFunction< git_diff_line_cbFunction> > - When iterating over a diff, callback that will be made per text diff line. In this context, the provided range will be NULL.
-
git_diff_line_cbFunction
= Int Function(Pointer<
git_diff_delta> delta, Pointer<git_diff_hunk> hunk, Pointer<git_diff_line> line, Pointer<Void> payload) -
git_diff_notify_cb
= Pointer<
NativeFunction< git_diff_notify_cbFunction> > - Diff notification callback function.
-
git_diff_notify_cbFunction
= Int Function(Pointer<
git_diff> diff_so_far, Pointer<git_diff_delta> delta_to_add, Pointer<Char> matched_pathspec, Pointer<Void> payload) -
git_diff_progress_cb
= Pointer<
NativeFunction< git_diff_progress_cbFunction> > - Diff progress callback.
-
git_diff_progress_cbFunction
= Int Function(Pointer<
git_diff> diff_so_far, Pointer<Char> old_path, Pointer<Char> new_path, Pointer<Void> payload) -
git_filter_apply_fn
= Pointer<
NativeFunction< git_filter_apply_fnFunction> > - Callback to actually perform the data filtering
-
git_filter_apply_fnFunction
= Int Function(Pointer<
git_filter> self, Pointer<Pointer< payload, Pointer<Void> >git_buf> to, Pointer<git_buf> from, Pointer<git_filter_source> src) -
git_filter_check_fn
= Pointer<
NativeFunction< git_filter_check_fnFunction> > - Callback to decide if a given source needs this filter
-
git_filter_check_fnFunction
= Int Function(Pointer<
git_filter> self, Pointer<Pointer< payload, Pointer<Void> >git_filter_source> src, Pointer<Pointer< attr_values)Char> > -
git_filter_cleanup_fn
= Pointer<
NativeFunction< git_filter_cleanup_fnFunction> > - Callback to clean up after filtering has been applied
-
git_filter_cleanup_fnFunction
= Void Function(Pointer<
git_filter> self, Pointer<Void> payload) -
git_filter_init_fn
= Pointer<
NativeFunction< git_filter_init_fnFunction> > - Initialize callback on filter
-
git_filter_init_fnFunction
= Int Function(Pointer<
git_filter> self) -
git_filter_shutdown_fn
= Pointer<
NativeFunction< git_filter_shutdown_fnFunction> > - Shutdown callback on filter
-
git_filter_shutdown_fnFunction
= Void Function(Pointer<
git_filter> self) -
git_filter_stream_fn
= Pointer<
NativeFunction< git_filter_stream_fnFunction> > - Callback to perform the data filtering.
-
git_filter_stream_fnFunction
= Int Function(Pointer<
Pointer< out, Pointer<git_writestream> >git_filter> self, Pointer<Pointer< payload, Pointer<Void> >git_filter_source> src, Pointer<git_writestream> next) -
git_index_matched_path_cb
= Pointer<
NativeFunction< git_attr_foreach_cbFunction> > - Callback for APIs that add/remove/update files matching pathspec
-
git_index_matched_path_cbFunction
= Int Function(Pointer<
Char> name, Pointer<Char> value, Pointer<Void> payload) -
git_indexer_progress_cb
= Pointer<
NativeFunction< git_indexer_progress_cbFunction> > - Type for progress callbacks during indexing. Return a value less than zero to cancel the indexing or download.
-
git_indexer_progress_cbFunction
= Int Function(Pointer<
git_indexer_progress> stats, Pointer<Void> payload) -
git_merge_driver_apply_fn
= Pointer<
NativeFunction< git_merge_driver_apply_fnFunction> > - Callback to perform the merge.
-
git_merge_driver_apply_fnFunction
= Int Function(Pointer<
git_merge_driver> self, Pointer<Pointer< path_out, Pointer<Char> >Uint32> mode_out, Pointer<git_buf> merged_out, Pointer<Char> filter_name, Pointer<git_merge_driver_source> src) -
git_merge_driver_init_fn
= Pointer<
NativeFunction< git_merge_driver_init_fnFunction> > - Initialize callback on merge driver
-
git_merge_driver_init_fnFunction
= Int Function(Pointer<
git_merge_driver> self) -
git_merge_driver_shutdown_fn
= Pointer<
NativeFunction< git_merge_driver_shutdown_fnFunction> > - Shutdown callback on merge driver
-
git_merge_driver_shutdown_fnFunction
= Void Function(Pointer<
git_merge_driver> self) -
git_note_foreach_cb
= Pointer<
NativeFunction< git_note_foreach_cbFunction> > - Callback for git_note_foreach.
-
git_note_foreach_cbFunction
= Int Function(Pointer<
git_oid> blob_id, Pointer<git_oid> annotated_object_id, Pointer<Void> payload) - git_note_iterator = git_iterator
- note iterator
- git_object_size_t = Uint64
- The maximum size of an object
-
git_odb_foreach_cb
= Pointer<
NativeFunction< git_odb_foreach_cbFunction> > - Function type for callbacks from git_odb_foreach.
-
git_odb_foreach_cbFunction
= Int Function(Pointer<
git_oid> id, Pointer<Void> payload) - git_off_t = Int64
- Note: Can't use off_t since if a client program includes <sys/types.h> before us (directly or indirectly), they'll get 32 bit off_t in their client app, even though /we/ define _FILE_OFFSET_BITS=64.
-
git_packbuilder_foreach_cb
= Pointer<
NativeFunction< git_packbuilder_foreach_cbFunction> > - Callback used to iterate over packed objects
-
git_packbuilder_foreach_cbFunction
= Int Function(Pointer<
Void> buf, Size size, Pointer<Void> payload) -
git_packbuilder_progress
= Pointer<
NativeFunction< git_packbuilder_progressFunction> > - Packbuilder progress notification function.
-
git_packbuilder_progressFunction
= Int Function(Int stage, Uint32 current, Uint32 total, Pointer<
Void> payload) -
git_push_negotiation
= Pointer<
NativeFunction< git_push_negotiationFunction> > - Callback used to inform of upcoming updates.
-
git_push_negotiationFunction
= Int Function(Pointer<
Pointer< updates, Size len, Pointer<git_push_update> >Void> payload) -
git_push_transfer_progress_cb
= Pointer<
NativeFunction< git_push_transfer_progress_cbFunction> > - Push network progress notification callback.
-
git_push_transfer_progress_cbFunction
= Int Function(UnsignedInt current, UnsignedInt total, Size bytes, Pointer<
Void> payload) -
git_push_update_reference_cb
= Pointer<
NativeFunction< git_attr_foreach_cbFunction> > - Callback used to inform of the update status from the remote.
-
git_push_update_reference_cbFunction
= Int Function(Pointer<
Char> name, Pointer<Char> value, Pointer<Void> payload) -
git_reference_foreach_cb
= Pointer<
NativeFunction< git_reference_foreach_cbFunction> > - Callback used to iterate over references
-
git_reference_foreach_cbFunction
= Int Function(Pointer<
git_reference> reference, Pointer<Void> payload) -
git_reference_foreach_name_cb
= Pointer<
NativeFunction< git_reference_foreach_name_cbFunction> > - Callback used to iterate over reference names
-
git_reference_foreach_name_cbFunction
= Int Function(Pointer<
Char> name, Pointer<Void> payload) -
git_remote_create_cb
= Pointer<
NativeFunction< git_remote_create_cbFunction> > - The signature of a function matching git_remote_create, with an additional void* as a callback payload.
-
git_remote_create_cbFunction
= Int Function(Pointer<
Pointer< out, Pointer<git_remote> >git_repository> repo, Pointer<Char> name, Pointer<Char> url, Pointer<Void> payload) -
git_remote_ready_cb
= Pointer<
NativeFunction< git_remote_ready_cbFunction> > -
Callback invoked immediately before we attempt to connect to the
given url. Callers may change the URL before the connection by
calling
git_remote_set_instance_urlin the callback. -
git_remote_ready_cbFunction
= Int Function(Pointer<
git_remote> remote, Int direction, Pointer<Void> payload) -
git_repository_create_cb
= Pointer<
NativeFunction< git_repository_create_cbFunction> > - The signature of a function matching git_repository_init, with an additional void * as callback payload.
-
git_repository_create_cbFunction
= Int Function(Pointer<
Pointer< out, Pointer<git_repository> >Char> path, Int bare, Pointer<Void> payload) -
git_repository_fetchhead_foreach_cb
= Pointer<
NativeFunction< git_repository_fetchhead_foreach_cbFunction> > - Callback used to iterate over each FETCH_HEAD entry
-
git_repository_fetchhead_foreach_cbFunction
= Int Function(Pointer<
Char> ref_name, Pointer<Char> remote_url, Pointer<git_oid> oid, UnsignedInt is_merge, Pointer<Void> payload) -
git_repository_mergehead_foreach_cb
= Pointer<
NativeFunction< git_odb_foreach_cbFunction> > - Callback used to iterate over each MERGE_HEAD entry
-
git_repository_mergehead_foreach_cbFunction
= Int Function(Pointer<
git_oid> id, Pointer<Void> payload) -
git_revwalk_hide_cb
= Pointer<
NativeFunction< git_odb_foreach_cbFunction> > - This is a callback function that user can provide to hide a commit and its parents. If the callback function returns non-zero value, then this commit and its parents will be hidden.
-
git_revwalk_hide_cbFunction
= Int Function(Pointer<
git_oid> id, Pointer<Void> payload) -
git_smart_subtransport_cb
= Pointer<
NativeFunction< git_smart_subtransport_cbFunction> > - A function that creates a new subtransport for the smart transport
-
git_smart_subtransport_cbFunction
= Int Function(Pointer<
Pointer< out, Pointer<git_smart_subtransport> >git_transport> owner, Pointer<Void> param) -
git_stash_apply_progress_cb
= Pointer<
NativeFunction< git_stash_apply_progress_cbFunction> > - Stash application progress notification function. Return 0 to continue processing, or a negative value to abort the stash application.
-
git_stash_apply_progress_cbFunction
= Int Function(UnsignedInt progress, Pointer<
Void> payload) -
git_stash_cb
= Pointer<
NativeFunction< git_stash_cbFunction> > - This is a callback function you can provide to iterate over all the stashed states that will be invoked per entry.
-
git_stash_cbFunction
= Int Function(Size index, Pointer<
Char> message, Pointer<git_oid> stash_id, Pointer<Void> payload) -
git_status_cb
= Pointer<
NativeFunction< git_status_cbFunction> > - Function pointer to receive status on individual files
-
git_status_cbFunction
= Int Function(Pointer<
Char> path, UnsignedInt status_flags, Pointer<Void> payload) -
git_stream_cb
= Pointer<
NativeFunction< git_stream_cbFunction> > - @deprecated Provide a git_stream_registration to git_stream_register @see git_stream_registration
-
git_stream_cbFunction
= Int Function(Pointer<
Pointer< out, Pointer<git_stream> >Char> host, Pointer<Char> port) -
git_submodule_cb
= Pointer<
NativeFunction< git_submodule_cbFunction> > - Function pointer to receive each submodule
-
git_submodule_cbFunction
= Int Function(Pointer<
git_submodule> sm, Pointer<Char> name, Pointer<Void> payload) -
git_tag_foreach_cb
= Pointer<
NativeFunction< git_tag_foreach_cbFunction> > - Callback used to iterate over tag names
-
git_tag_foreach_cbFunction
= Int Function(Pointer<
Char> name, Pointer<git_oid> oid, Pointer<Void> payload) - git_time_t = Int64
-
git_transport_cb
= Pointer<
NativeFunction< git_transport_cbFunction> > - Signature of a function which creates a transport.
-
git_transport_cbFunction
= Int Function(Pointer<
Pointer< out, Pointer<git_transport> >git_remote> owner, Pointer<Void> param) -
git_transport_certificate_check_cb
= Pointer<
NativeFunction< git_transport_certificate_check_cbFunction> > - Callback for the user's custom certificate checks.
-
git_transport_certificate_check_cbFunction
= Int Function(Pointer<
git_cert> cert, Int valid, Pointer<Char> host, Pointer<Void> payload) -
git_transport_message_cb
= Pointer<
NativeFunction< git_transport_message_cbFunction> > - Callback for messages received by the transport.
-
git_transport_message_cbFunction
= Int Function(Pointer<
Char> str, Int len, Pointer<Void> payload) -
git_treebuilder_filter_cb
= Pointer<
NativeFunction< git_treebuilder_filter_cbFunction> > - Callback for git_treebuilder_filter
-
git_treebuilder_filter_cbFunction
= Int Function(Pointer<
git_tree_entry> entry, Pointer<Void> payload) -
git_treewalk_cb
= Pointer<
NativeFunction< git_treewalk_cbFunction> > - Callback for the tree traversal method.
-
git_treewalk_cbFunction
= Int Function(Pointer<
Char> root, Pointer<git_tree_entry> entry, Pointer<Void> payload) -
git_url_resolve_cb
= Pointer<
NativeFunction< git_url_resolve_cbFunction> > - Callback to resolve URLs before connecting to remote
-
git_url_resolve_cbFunction
= Int Function(Pointer<
git_buf> url_resolved, Pointer<Char> url, Int direction, Pointer<Void> payload) - id_t = __id_t
- ino_t = __ino_t
- int_fast16_t = Long
- int_fast32_t = Long
- int_fast64_t = Long
- int_fast8_t = SignedChar
- int_least16_t = __int_least16_t
- int_least32_t = __int_least32_t
- int_least64_t = __int_least64_t
- int_least8_t = __int_least8_t
- intmax_t = __intmax_t
- key_t = __key_t
- LIBSSH2_SESSION = _LIBSSH2_SESSION
- LIBSSH2_USERAUTH_KBDINT_PROMPT = _LIBSSH2_USERAUTH_KBDINT_PROMPT
- LIBSSH2_USERAUTH_KBDINT_RESPONSE = _LIBSSH2_USERAUTH_KBDINT_RESPONSE
- locale_t = __locale_t
- loff_t = __loff_t
- mode_t = __mode_t
- nlink_t = __nlink_t
- off_t = __off_t
- pid_t = __pid_t
- pthread_key_t = UnsignedInt
- pthread_once_t = Int
- pthread_t = UnsignedLong
- quad_t = __quad_t
- register_t = Long
- sigset_t = __sigset_t
- ssize_t = __ssize_t
- suseconds_t = __suseconds_t
- time_t = __time_t
- timer_t = __timer_t
- u_char = __u_char
- u_int = __u_int
- u_int16_t = __uint16_t
- u_int32_t = __uint32_t
- u_int64_t = __uint64_t
- u_int8_t = __uint8_t
- u_long = __u_long
- u_quad_t = __u_quad_t
- u_short = __u_short
- uid_t = __uid_t
- uint = UnsignedInt
- uint_fast16_t = UnsignedLong
- uint_fast32_t = UnsignedLong
- uint_fast64_t = UnsignedLong
- uint_fast8_t = UnsignedChar
- uint_least16_t = __uint_least16_t
- uint_least32_t = __uint_least32_t
- uint_least64_t = __uint_least64_t
- uint_least8_t = __uint_least8_t
- uintmax_t = __uintmax_t
- ulong = UnsignedLong
- ushort = UnsignedShort