git_blame_flag_t enum
Flags for indicating option behavior for git_blame APIs.
Values
- GIT_BLAME_NORMAL → const git_blame_flag_t
-
Normal blame, the default
const git_blame_flag_t(0) - GIT_BLAME_TRACK_COPIES_SAME_FILE → const git_blame_flag_t
-
Track lines that have moved within a file (like
git blame -M).This is not yet implemented and reserved for future use.
const git_blame_flag_t(1) - GIT_BLAME_TRACK_COPIES_SAME_COMMIT_MOVES → const git_blame_flag_t
-
Track lines that have moved across files in the same commit (like
git blame -C).This is not yet implemented and reserved for future use.
const git_blame_flag_t(2) - GIT_BLAME_TRACK_COPIES_SAME_COMMIT_COPIES → const git_blame_flag_t
-
Track lines that have been copied from another file that exists in the same commit (like
git blame -CC). Implies SAME_FILE.This is not yet implemented and reserved for future use.
const git_blame_flag_t(4) - GIT_BLAME_TRACK_COPIES_ANY_COMMIT_COPIES → const git_blame_flag_t
-
Track lines that have been copied from another file that exists in any commit (like
git blame -CCC). Implies SAME_COMMIT_COPIES.This is not yet implemented and reserved for future use.
const git_blame_flag_t(8) - GIT_BLAME_FIRST_PARENT → const git_blame_flag_t
-
Restrict the search of commits to those reachable following only the first parents.
const git_blame_flag_t(16) - GIT_BLAME_USE_MAILMAP → const git_blame_flag_t
-
Use mailmap file to map author and committer names and email addresses to canonical real names and email addresses. The mailmap will be read from the working directory, or HEAD in a bare repository.
const git_blame_flag_t(32) - GIT_BLAME_IGNORE_WHITESPACE → const git_blame_flag_t
-
Ignore whitespace differences
const git_blame_flag_t(64)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → git_blame_flag_t
Constants
-
values
→ const List<
git_blame_flag_t> - A constant List of the values in this enum, in order of their declaration.