git_cert_hostkey class final
Hostkey information taken from libssh2
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
hash_md5
↔ Array<
UnsignedChar> -
Hostkey hash. If
typehasGIT_CERT_SSH_MD5set, this will have the MD5 hash of the hostkey.getter/setter pair -
hash_sha1
↔ Array<
UnsignedChar> -
Hostkey hash. If
typehasGIT_CERT_SSH_SHA1set, this will have the SHA-1 hash of the hostkey.getter/setter pair -
hash_sha256
↔ Array<
UnsignedChar> -
Hostkey hash. If
typehasGIT_CERT_SSH_SHA256set, this will have the SHA-256 hash of the hostkey.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
-
hostkey
↔ Pointer<
Char> -
Pointer to the raw hostkey. If
typehasGIT_CERT_SSH_RAWset, this will have the raw contents of the hostkey.getter/setter pair - hostkey_len ↔ int
-
Raw hostkey length. If
typehasGIT_CERT_SSH_RAWset, this will have the length of the raw contents of the hostkey.getter/setter pair - parent ↔ git_cert
-
< The parent cert
getter/setter pair
- raw_type → git_cert_ssh_raw_type_t
-
no setter
- raw_typeAsInt ↔ int
-
Raw hostkey type. If
typehasGIT_CERT_SSH_RAWset, this will have the type of the raw hostkey.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → git_cert_ssh_t
-
no setter
- typeAsInt ↔ int
-
A bitmask containing the available fields.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited