git_credential_ssh_interactive class final
Keyboard-interactive based ssh authentication
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- parent ↔ git_credential
-
< The parent credential
getter/setter pair
-
payload
↔ Pointer<
Void> -
< Payload passed to prompt_callback
getter/setter pair
- prompt_callback ↔ git_credential_ssh_interactive_cb
-
Callback used for authentication.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
username
↔ Pointer<
Char> -
< The username to authenticate as
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited