git_reference_iterator class final
Every backend's iterator must have a pointer to itself as the first element, so the API can talk to it. You'd define your iterator as
struct my_iterator { git_reference_iterator parent; ... }
and assign iter->parent.backend to your git_refdb_backend.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
db
↔ Pointer<
git_refdb> -
getter/setter pair
-
free
↔ Pointer<
NativeFunction< Void Function(Pointer< >git_reference_iterator> iter)> -
Free the iterator
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
next
↔ Pointer<
NativeFunction< Int Function(Pointer< >Pointer< ref, Pointer<git_reference> >git_reference_iterator> iter)> -
Return the current reference and advance the iterator.
getter/setter pair
-
next_name
↔ Pointer<
NativeFunction< Int Function(Pointer< >Pointer< ref_name, Pointer<Char> >git_reference_iterator> iter)> -
Return the name of the current reference and advance the iterator
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited