git_status_options class final
Options to control how git_status_foreach_ext() will issue callbacks.
Initialize with GIT_STATUS_OPTIONS_INIT. Alternatively, you can
use git_status_options_init.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
baseline
↔ Pointer<
git_tree> -
The
baselineis the tree to be used for comparison to the working directory and index; defaults to HEAD.getter/setter pair - flags ↔ int
-
The
flagsvalue is an OR'ed combination of thegit_status_opt_tvalues above. The default isGIT_STATUS_OPT_DEFAULTS, which matches git's default behavior.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- pathspec ↔ git_strarray
-
The
pathspecis an array of path patterns to match (using fnmatch-style matching), or just an array of paths to match exactly ifGIT_STATUS_OPT_DISABLE_PATHSPEC_MATCHis specified in the flags.getter/setter pair - rename_threshold ↔ int
-
Threshold above which similar files will be considered renames.
This is equivalent to the -M option. Defaults to 50.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show$ → git_status_show_t
-
no setter
- show$AsInt ↔ int
-
The
showvalue is one of thegit_status_show_tconstants that control which files to scan and in what order. The default isGIT_STATUS_SHOW_INDEX_AND_WORKDIR.getter/setter pair - version ↔ int
-
The struct version; pass
GIT_STATUS_OPTIONS_VERSION.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited