git_submodule_status_t enum
Return codes for submodule status.
A combination of these flags will be returned to describe the status of a submodule. Depending on the "ignore" property of the submodule, some of the flags may never be returned because they indicate changes that are supposed to be ignored.
Submodule info is contained in 4 places: the HEAD tree, the index, config files (both .git/config and .gitmodules), and the working directory. Any or all of those places might be missing information about the submodule depending on what state the repo is in. We consider all four places to build the combination of status flags.
There are four values that are not really status, but give basic info about what sources of submodule data are available. These will be returned even if ignore is set to "ALL".
- IN_HEAD - superproject head contains submodule
- IN_INDEX - superproject index contains submodule
- IN_CONFIG - superproject gitmodules has submodule
- IN_WD - superproject workdir has submodule
The following values will be returned so long as ignore is not "ALL".
- INDEX_ADDED - in index, not in head
- INDEX_DELETED - in head, not in index
- INDEX_MODIFIED - index and head don't match
- WD_UNINITIALIZED - workdir contains empty directory
- WD_ADDED - in workdir, not index
- WD_DELETED - in index, not workdir
- WD_MODIFIED - index and workdir head don't match
The following can only be returned if ignore is "NONE" or "UNTRACKED".
- WD_INDEX_MODIFIED - submodule workdir index is dirty
- WD_WD_MODIFIED - submodule workdir has modified files
Lastly, the following will only be returned for ignore "NONE".
- WD_UNTRACKED - wd contains untracked files
Values
- GIT_SUBMODULE_STATUS_IN_HEAD → const git_submodule_status_t
-
const git_submodule_status_t(1) - GIT_SUBMODULE_STATUS_IN_INDEX → const git_submodule_status_t
-
const git_submodule_status_t(2) - GIT_SUBMODULE_STATUS_IN_CONFIG → const git_submodule_status_t
-
const git_submodule_status_t(4) - GIT_SUBMODULE_STATUS_IN_WD → const git_submodule_status_t
-
const git_submodule_status_t(8) - GIT_SUBMODULE_STATUS_INDEX_ADDED → const git_submodule_status_t
-
const git_submodule_status_t(16) - GIT_SUBMODULE_STATUS_INDEX_DELETED → const git_submodule_status_t
-
const git_submodule_status_t(32) - GIT_SUBMODULE_STATUS_INDEX_MODIFIED → const git_submodule_status_t
-
const git_submodule_status_t(64) - GIT_SUBMODULE_STATUS_WD_UNINITIALIZED → const git_submodule_status_t
-
const git_submodule_status_t(128) - GIT_SUBMODULE_STATUS_WD_ADDED → const git_submodule_status_t
-
const git_submodule_status_t(256) - GIT_SUBMODULE_STATUS_WD_DELETED → const git_submodule_status_t
-
const git_submodule_status_t(512) - GIT_SUBMODULE_STATUS_WD_MODIFIED → const git_submodule_status_t
-
const git_submodule_status_t(1024) - GIT_SUBMODULE_STATUS_WD_INDEX_MODIFIED → const git_submodule_status_t
-
const git_submodule_status_t(2048) - GIT_SUBMODULE_STATUS_WD_WD_MODIFIED → const git_submodule_status_t
-
const git_submodule_status_t(4096) - GIT_SUBMODULE_STATUS_WD_UNTRACKED → const git_submodule_status_t
-
const git_submodule_status_t(8192)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → git_submodule_status_t
Constants
-
values
→ const List<
git_submodule_status_t> - A constant List of the values in this enum, in order of their declaration.